==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Irá remover todas as assinaturas desta petição. Deseja continuar?',
	'aucune_signature' => 'Sem assinaturas',

	// B
	'bouton_checkbox_envoi_message' => 'possibilidade de enviar uma mensagem',
	'bouton_checkbox_indiquer_site' => 'necessita de indicar um sítio web',
	'bouton_checkbox_signature_unique_email' => 'apenas uma assinatura por e-mail',
	'bouton_checkbox_signature_unique_site' => 'apenas uma assinatura por sítio web',

	// F
	'filtre' => 'Filtro :',
	'form_pet_adresse_site' => 'Endereço do seu sítio',
	'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este código...',
	'form_pet_confirmation' => 'Por favor confirme a sua assinatura:',
	'form_pet_deja_signe' => 'Já assinou este texto.',
	'form_pet_envoi_mail_confirmation' => 'Um e-mail de confirmação acabou de lhe ser enviado @email@. Deverá visitar o endereço do sítio Web mencionado neste correio para validar a sua assinatura',
	'form_pet_mail_confirmation' => 'Bom dia, 

Pediu para assinar a petição :
@titre@.

Forneceu as seguintes informações :
    Nome: @nom_email@
    Sítio: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para validar a sua assinatura, basta ligar-se ao
 endereço abaixo indicado (caso contrário, o seu pedido será rejeitado) :

    @url@


Obrigado pela sua participação
',
	'form_pet_message_commentaire' => 'Uma mensagem, um comentário?',
	'form_pet_nom_site2' => 'Nome do seu sítio Web',
	'form_pet_probleme_liens' => 'Por favor edite a sua mensagem, removendo todas as hiperligações.',
	'form_pet_probleme_technique' => 'Problema técnico: as assinaturas estão temporariamente suspensas.',
	'form_pet_signature_validee' => 'A sua assinatura foi validada. Obrigado!',
	'form_pet_site_deja_enregistre' => 'Este sítio já está registado',
	'form_pet_url_invalide' => 'O URL que indicou não é válido.',
	'form_pet_votre_email' => 'O seu endereço e-mail',
	'form_pet_votre_nom' => 'O seu nome ou pseudónimo',
	'form_pet_votre_site' => 'Se tem um sítio Web, pode indicá-lo a seguir',

	// I
	'icone_relancer_signataire' => 'Contactar o signatário novamente',
	'icone_relancer_signataires' => 'Contactar os signatários novamente',
	'icone_suivi_petitions' => 'Seguir/Gerir as petições',
	'icone_supprimer_signature' => 'Eliminar este assinatura',
	'icone_supprimer_signatures' => 'Eliminar as assinaturas',
	'icone_valider_signature' => 'Confirmar esta assinatura',
	'icone_valider_signatures' => 'Confirmar as assinaturas',
	'info_adresse_email' => 'ENDEREÇO E-MAIL :',
	'info_fonctionnement_petition' => 'Configuração da petição:',
	'info_signature_supprimee' => 'Assinatura eliminada',
	'info_signature_supprimee_erreur' => 'Erro : este código de eliminação não corresponde a nenhuma assinatura',
	'info_site_web' => 'SÍTIO WEB :',
	'info_texte_message' => 'Texto da sua mensagem :',

	// L
	'lien_reponse_article' => 'Comentário ao artigo',

	// N
	'nombre_signatures' => '@nb@ assinaturas',

	// S
	'sans_nom' => 'Anónimo',
	'signatures_article' => 'Assinaturas do artigo:',
	'signatures_aucune' => 'Nenhum',
	'signatures_meme_auteur' => 'Assinaturas do mesmo autor',
	'signatures_meme_site' => 'Assinaturas com o mesmo sítio web',
	'signatures_poubelle' => 'Eliminadas',
	'signatures_prop' => 'Em espera',
	'signatures_publie' => 'Confirmadas',
	'signatures_recherche_label' => 'Procurar assinaturas:',
	'signatures_selection' => 'Seleccionar as assinaturas :',
	'signatures_toutes' => 'Todas',
	'statut_poubelle' => 'Eliminada',
	'statut_prop' => 'Aguardando validação',
	'statut_publie' => 'Confirmado',

	// T
	'texte_descriptif_petition' => 'Descrição da petição',
	'titre_page_controle_petition' => 'Acompanhamento das petições',
	'titre_petition' => 'Petição',
	'titre_petitions' => 'Petições',
	'titre_selection_action' => 'Selecção',
	'titre_signatures_attente' => 'Assianturas aguardando validação',
	'titre_signatures_publie' => 'Assinaturas confirmadas',
	'titre_suivi_petition' => 'Acompanhamento das petições',
	'tout_voir' => 'Visualizar todas as assinaturas',

	// U
	'une_signature' => '1 assinatura',

	// V
	'voir_signatures_objet' => 'Visualizar as assinaturas'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/petitions/lang/petitions_pt.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/petitions?lang_cible=pt
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'alerte_confirmer_suppression_signatures' => 'Irá remover todas as assinaturas desta petição. Deseja continuar?',
	'aucune_signature' => 'Sem assinaturas',

	// B
	'bouton_checkbox_envoi_message' => 'possibilidade de enviar uma mensagem',
	'bouton_checkbox_indiquer_site' => 'necessita de indicar um sítio web',
	'bouton_checkbox_signature_unique_email' => 'apenas uma assinatura por e-mail',
	'bouton_checkbox_signature_unique_site' => 'apenas uma assinatura por sítio web',
	'bouton_radio_activer_petition' => 'Activar a petição',
	'bouton_radio_pas_petition' => 'Sem petição',
	'bouton_radio_petition_activee' => 'Petição activada',
	'bouton_radio_supprimer_petition' => 'Suprimir a petição',

	// F
	'filtre' => 'Filtro :',
	'form_pet_adresse_site' => 'Endereço do seu sítio',
	'form_pet_aucune_signature' => 'Nenhuma assinatura corresponde a este código...',
	'form_pet_confirmation' => 'Por favor confirme a sua assinatura:',
	'form_pet_deja_signe' => 'Já assinou este texto.',
	'form_pet_envoi_mail_confirmation' => 'Um e-mail de confirmação acabou de lhe ser enviado @email@. Deverá visitar o endereço do sítio Web mencionado neste correio para validar a sua assinatura',
	'form_pet_mail_confirmation' => 'Bom dia, 

Pediu para assinar a petição :
@titre@.

Forneceu as seguintes informações :
    Nome: @nom_email@
    Sítio: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para validar a sua assinatura, basta ligar-se ao
 endereço abaixo indicado (caso contrário, o seu pedido será rejeitado) :

    @url@


Obrigado pela sua participação
',
	'form_pet_message_commentaire' => 'Uma mensagem, um comentário?',
	'form_pet_nom_site2' => 'Nome do seu sítio Web',
	'form_pet_probleme_liens' => 'Por favor edite a sua mensagem, removendo todas as hiperligações.',
	'form_pet_probleme_technique' => 'Problema técnico: as assinaturas estão temporariamente suspensas.',
	'form_pet_signature_validee' => 'A sua assinatura foi validada. Obrigado!',
	'form_pet_site_deja_enregistre' => 'Este sítio já está registado',
	'form_pet_url_invalide' => 'O URL que indicou não é válido.',
	'form_pet_votre_email' => 'O seu endereço e-mail',
	'form_pet_votre_nom' => 'O seu nome ou pseudónimo',
	'form_pet_votre_site' => 'Se tem um sítio Web, pode indicá-lo a seguir',

	// I
	'icone_relancer_signataire' => 'Contactar o signatário novamente',
	'icone_relancer_signataires' => 'Contactar os signatários novamente',
	'icone_suivi_petitions' => 'Seguir/Gerir as petições',
	'icone_supprimer_signature' => 'Eliminar este assinatura',
	'icone_supprimer_signatures' => 'Eliminar as assinaturas',
	'icone_valider_signature' => 'Confirmar esta assinatura',
	'icone_valider_signatures' => 'Confirmar as assinaturas',
	'info_adresse_email' => 'ENDEREÇO E-MAIL :',
	'info_fonctionnement_petition' => 'Configuração da petição:',
	'info_signature_supprimee' => 'Assinatura eliminada',
	'info_signature_supprimee_erreur' => 'Erro : este código de eliminação não corresponde a nenhuma assinatura',
	'info_site_web' => 'SÍTIO WEB :',
	'info_texte_message' => 'Texto da sua mensagem :',

	// L
	'lien_reponse_article' => 'Comentário ao artigo',

	// N
	'nombre_signatures' => '@nb@ assinaturas',

	// S
	'sans_nom' => 'Anónimo',
	'signatures_article' => 'Assinaturas do artigo:',
	'signatures_aucune' => 'Nenhum',
	'signatures_meme_auteur' => 'Assinaturas do mesmo autor',
	'signatures_meme_site' => 'Assinaturas com o mesmo sítio web',
	'signatures_poubelle' => 'Eliminadas',
	'signatures_prop' => 'Em espera',
	'signatures_publie' => 'Confirmadas',
	'signatures_recherche_label' => 'Procurar assinaturas:',
	'signatures_selection' => 'Seleccionar as assinaturas :',
	'signatures_toutes' => 'Todas',
	'statut_poubelle' => 'Eliminada',
	'statut_prop' => 'Aguardando validação',
	'statut_publie' => 'Confirmado',

	// T
	'texte_descriptif_petition' => 'Descrição da petição',
	'titre_page_controle_petition' => 'Acompanhamento das petições',
	'titre_petition' => 'Petição',
	'titre_petitions' => 'Petições',
	'titre_selection_action' => 'Selecção',
	'titre_signatures_attente' => 'Assianturas aguardando validação',
	'titre_signatures_publie' => 'Assinaturas confirmadas',
	'titre_suivi_petition' => 'Acompanhamento das petições',
	'tout_voir' => 'Visualizar todas as assinaturas',

	// U
	'une_signature' => '1 assinatura',

	// V
	'voir_signatures_objet' => 'Visualizar as assinaturas'
);

?>
